\name{MatrixExp}
\title{Matrix exponential}
\alias{MatrixExp}
\description{
  Calculates the exponential of a square matrix.
}
\usage{
MatrixExp(mat, t = 1, n = 20, k = 3)
}
\arguments{
  \item{mat}{A square matrix}
  \item{t}{An optional scaling factor for the eigenvalues of \code{mat}}
  \item{n}{Number of terms in the series approximation to the
    exponential}
  \item{k}{Underflow correction factor}
}
\value{
  The exponentiated matrix \eqn{exp(mat)}.
}
\details{
  The exponential \eqn{E} of a square matrix \eqn{M} is calculated as 

  \deqn{E = U exp(D) U^{-1}}

  where \eqn{D} is a diagonal matrix with the eigenvalues
  of \eqn{M} on the diagonal, \eqn{exp(D)} is a diagonal matrix with the
  exponentiated eigenvalues
  of \eqn{M} on the diagonal, and \eqn{U} is a matrix whose columns are the
  eigenvectors of \eqn{M}.

  However, if \eqn{M} has repeated eigenvalues, then its eigenvector
  matrix is non-invertible. In this case, the matrix exponential is
  calculated using a power series approximation,

  \deqn{exp(M) = I + M + M^2/2 + M^3 / 3! + M^4 / 4! + ...}

  For a continuous-time homogeneous Markov process with transition
intensity matrix
  \eqn{Q},  the probability of occupying state \eqn{s} at time \eqn{u + t}
  conditional on occupying state \eqn{r} at time \eqn{u} is given by the
  \eqn{(r,s)} entry of the matrix \eqn{exp(tQ)}. 
  
  The series approximation method was adapted from the corresponding
  function in Jim Lindsey's \code{rmutil} library.
}
\references{
  Cox, D. R. and Miller, H. D. \emph{The theory of stochastic
    processes}, Chapman and Hall, London (1965)
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{math}
\eof
\name{aneur}
\alias{aneur}
\title{Aortic aneurysm progression data}
\description{
  This dataset contains a list of transitions between
  grades of aortic aneurysms, measured by ultrasound examination of the
  diameter of the aorta. 
  
}
\usage{data(aneur)}

\format{
  A data frame containing 2662 rows. Columns correspond to
  'starting state', 'end state', 'time interval', 'age at beginning of
  interval'.  The stages represent successive degrees of aneurysm
  severity. 

  \tabular{rll}{
    Stage 1 \tab Aneurysm-free \tab < 30 cm \cr
    Stage 2 \tab Mild aneurysm \tab 30-44 cm \cr
    Stage 3 \tab Moderate aneurysm \tab 45-54 cm \cr
    Stage 4 \tab Severe aneurysm \tab > 55 cm \cr
  }
  
  These were obtained from 4337 ultrasound scans from 838 men over 65.
  683 of these men were aneurysm-free at age 65 and were re-screened every two
  years.  The remaining men were aneurysmal at entry and had successive
  screens with frequency depending on the stage of the aneurysm.
  Stage 4 aneurysms are repaired by surgery.
}

\source{
  The Chichester, U.K. randomised controlled trial of screening for
  abdominal aortic aneurysms by ultrasonography.
}

\references{
  Couto, E. and Duffy, S. W. and Ashton, H. A. and Walker, N. M.
  and Myles, J. P. and Scott, R. A. P. and Thompson, S. G. (2002)
  \emph{Probabilities of progression of aortic aneurysms: estimates
    and implications for screening policy}
  Journal of Medical Screening 9(1):40--42
}

\keyword{datasets}
\eof
\name{coef.msm}
\alias{coef.msm}
\title{Extract model coefficients}
\description{
  Extract the estimated log transition intensities and the corresponding
  linear effects of each covariate. 
}
\usage{
\method{coef}{msm}(object, \dots)
}
\arguments{
  \item{object}{A fitted multi-state model object, as returned by
    \code{\link{msm}}.}
  \item{...}{(unused) further arguments passed to or from other methods.}
}
\value{
  If there is no misclassification, \code{coef.msm} returns a list of matrices.
  The first component, labelled \code{logbaseline}, is a matrix containing the estimated
  transition intensities on the log scale with any covariates fixed at
  their means in the data. Each remaining component is a matrix giving the linear
  effects of the labelled covariate on the matrix of log
  intensities. \cr

  
  For misclassification models, \code{coef.msm} returns a list of
  lists. The first component, \code{Qmatrices}, is a list of matrices as described in the
  previous paragraph.  The additional component \code{Ematrices} is a
  list of similar format containing the logit-misclassification
  probabilities and any estimated covariate effects. 
}
\seealso{
  \code{\link{msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{crudeinits.msm}
\alias{crudeinits.msm}
\title{Calculate crude initial values for transition intensities}
\description{
  Calculates crude initial values for transition intensities by assuming
  that the data represent the exact transition times of the Markov
  process. 
}
\usage{
crudeinits.msm(state, time, subject, qmatrix, data=NULL, fromto=FALSE,
               fromstate=NULL, tostate=NULL, timelag=NULL, check=FALSE)
}
\arguments{
  \item{state}{Observed states, assumed to be ordered by time
  within each subject.}
  \item{time}{Times at which the elements of \code{state} were observed.}
  \item{subject}{Subject identification numbers corresponding to
    \code{state}. If not given, all observations are assumed to be on
    the same subject.}

  \item{data}{An optional data frame in which the variables represented
    by \code{subject} and \code{state} can be found.}

  \item{qmatrix}{Matrix of indicators for the allowed
    transitions.  Specified as described in the help page for
    \code{\link{msm}}.  An initial value will be estimated for each
    value of qmatrix that is 1.}

  \item{fromto}{If \code{TRUE}, then the data are given as three vectors, 
    \emph{from-state, to-state, time-difference},
    representing the set of observed transitions between states, and the
    time taken by each one. Otherwise, the data are given by \code{formula},
    containing observation times, corresponding observed states, and a
    vector of corresponding subject identification numbers \code{subject}.
  }
  \item{fromstate}{ Starting states for the observed transitions
    (required if \code{fromto == TRUE} ). }

  \item{tostate}{ Finishing states for the observed transitions
    (required if \code{fromto == TRUE} ). }

  \item{timelag}{ Time difference between observing \code{fromstate}
    and \code{tostate}  (required if \code{fromto == TRUE} ). }

  \item{check}{ Should the supplied state, time and subject data
    be checked for inconsistency with the supplied \code{qmatrix}, for
    example, backward transitions in the data with a forward progression
    model.  This check is rather slow, and not performed by default. }
}
\value{
  A named vector of estimates for the initial values of each transition
  intensity.  For simple models with no covariates, this can be used as
  the \code{inits} argument to \code{\link{msm}}.
}
\details{

  If we observe \eqn{n_{rs}}{n_rs} transitions from state \eqn{r} to state \eqn{s}, and a
  total of \eqn{n_r} transitions from state \eqn{r}, then \eqn{q_{rs} /
    q_{rr}}{q_rs / q_rr} can be estimated by \eqn{n_{rs} / n_r}{n_rs / n_r}. Then, given a total of \eqn{T_r} years
  spent in state \eqn{r},  the mean sojourn time \eqn{1 / q_{rr}}{1 / q_rr} can be estimated as \eqn{T_r / n_r}.
  Thus, \eqn{n_{rs} / T_r}{n_rs / T_r} is a crude estimate of \eqn{q_{rs}}{q_rs}.

}
\seealso{
  \code{\link{statetable.msm}}
}
\examples{
## Aortic aneurysm growth data
data(aneur)

## Three-state one-way progression model 
oneway.q <- rbind( c(0, 1, 0, 0), c(0, 0, 1, 0), c(0, 0, 0, 1), c(0, 0, 0, 0))

## Crude initial values for 1-2, 2-3 and 3-4 transition intensities 
crudeinits.msm(fromstate=from, tostate=to, timelag=dt, fromto=TRUE,
               data=aneur, qmatrix=oneway.q)
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{}
\eof
\name{deltamethod}
\title{The delta method}
\alias{deltamethod}
\description{
  Delta method for approximating the standard error of a transformation
  \eqn{g(X)} of a random variable \eqn{X = (x1, x2, \ldots)}, given estimates of the
  mean and covariance matrix of \eqn{X}.
}
\usage{
deltamethod(g, mean, cov, ses=TRUE)
}
\arguments{
  \item{g}{A formula representing the transformation. It must have
    arguments labelled \code{x1, x2,\ldots} For example,
    
    \code{~ 1 / (x1 + x2)}

    If the
    transformation returns a vector, then a list of formulae g1, g2,
    \ldots can be provided, for example

    \code{list( ~ x1 + x2,    ~ x1 / (x1 + x2) )}}

    \item{mean}{The estimated mean of \eqn{X}}

    \item{cov}{The estimated covariance matrix of \eqn{X}}

    \item{ses}{If \code{TRUE}, then the standard errors of \eqn{g1(X), g2(X),\ldots} are
      returned. Otherwise the covariance matrix of \eqn{g(X)} is returned.}
  }
}
\value{
  A vector containing the standard errors of \eqn{g1(X), g2(X),\ldots}
  or a matrix containing the covariance of \eqn{g(X)}.
}
\details{
  The delta method expands a differentiable function of a random
  variable about its mean, usually with a first-order Taylor approximation,
  and then takes the variance. For example, an approximation to
  the covariance matrix of \eqn{g(X)} is given by
  
  \deqn{ Cov(g(X)) = g'(mu) Cov(X) [g'(mu)]^T }

  where \eqn{mu} is an estimate of the mean of \eqn{X}.
}
\references{Oehlert, G. W. \emph{A note on the delta method}. American
  Statistician 46(1), 1992}}
}
\examples{

## Simple linear regression, E(y) = alpha + beta x 
x <- 1:100
y <- rnorm(100, 4*x, 5)
toy.lm <- lm(y ~ x)
estmean <- coef(toy.lm)
estvar <- summary(toy.lm)$cov.unscaled

## Approximate standard error of (1 / (alphahat + betahat))
deltamethod (~ 1 / (x1 + x2), estmean, estvar) 
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{math}
\eof
\name{ematrix.msm}
\alias{ematrix.msm}
\title{Misclassification probability matrix}
\description{
  Extract the estimated misclassification probability matrix, and the
  corresponding standard errors,  from a fitted multi-state
  model at a given set of covariate values. 
}
\usage{
ematrix.msm(x, covariates="mean")
}
\arguments{
  
  \item{x}{A fitted multi-state model, as returned by \code{\link{msm}}}.

  \item{covariates}{

    The covariate values for which to estimate the misclassification
    probability matrix.  This can either be:\cr

    the string \code{"mean"}, denoting the means of the covariates in
    the data (this is the default),\cr

    the number \code{0}, indicating that all the covariates should be
    set to zero,\cr

    or a list of values, with optional names. For example

    \code{list (60, 1)}

    where the order of the list follows the order of the covariates
    originally given in the model formula, or a named list, 

    \code{list (age = 60, sex = 1)}
  }
 
}
\value{
  A list with components:

  \item{\code{estimate}}{Estimated misclassification probability matrix.}  
  \item{\code{SE}}{Corresponding approximate standard errors.}

}
\details{
  Misclassification probabilities and covariate effects are estimated on the logit
  scale by \code{\link{msm}}. A covariance matrix is estimated from the
  Hessian of the maximised log-likelihood.  The delta method is used to
  obtain from these the standard error of the probabilities on the
  natural scale at arbitrary covariate values. 
}
\seealso{
  \code{\link{qmatrix.msm}}
}
\examples{
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{expit}
\alias{expit}
\title{Inverse logit function}
\description{Inverse logit function}
\usage{expit(x)
}
\arguments{
  \item{x}{ }
}
\value{
  \eqn{exp(x) / (1 + exp(x))}
}
\seealso{
  \code{\link{logit}}
}
\keyword{}
\eof
\name{hazard.msm}
\title{Calculate tables of hazard ratios for covariates on transition intensities}
\alias{hazard.msm}
\description{
  Hazard ratios are computed by exponentiating the
  estimated covariate effects on the log-transition intensities.
  This function is called by \code{\link{summary.msm}}.
}
\usage{
hazard.msm(x, hazard.scale = 1)
}
\arguments{
  \item{x}{Output from \code{\link{msm}} representing a fitted
    multi-state model.}

  \item{hazard.scale}{Vector with same elements as number of covariates
    on transition rates. Corresponds to the increase in each covariate
    used to calculate its hazard ratio. Defaults to all 1.}
}
\value{

  A list of tables containing hazard ratio estimates, one table for each covariate.
  Each table has three columns, containing the hazard ratio, and an
  approximate upper 95\% and lower 95\% confidence limit respectively
  (assuming normality of the estimator), for each Markov chain transition intensity. 

}
\seealso{
  \code{\link{msm}}, \code{\link{summary.msm}}, \code{\link{odds.msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{heart}
\alias{heart}
\title{Heart transplant monitoring data}
\description{
  A series of approximately yearly angiographic examinations of heart transplant
  recipients.  The state at each time is a grade of coronary artery
  vasculopathy (CAV),  a deterioration of the arterial walls.  
}
\usage{data(heart)}

\format{
  A data frame containing 2846 rows.  There are 622 patients, the rows
  are grouped by patient number and ordered by years after transplant,
  with each row representing an examination and containing additional
  covariates.
  
  \tabular{rll}{
    PTNUM   \tab (numeric) \tab Patient identification number \cr
    age     \tab (numeric) \tab Recipient age at examination (years) \cr
    years   \tab (numeric) \tab Examination time (years after transplant)\cr
    dage    \tab (numeric) \tab Age of heart donor (years) \cr
    sex   \tab (character) \tab sex (0=male, 1=female) \cr
    pdiag \tab (character) \tab Primary diagnosis (reason for
    transplant) IHD=ischaemic heart disease, IDC=idiopathic dilated
    cardiomyopathy. \cr
    cumrej     \tab (numeric) \tab Cumulative number of acute rejection
    episodes \cr
    state \tab (numeric) \tab State at the examination. Grade 1 represents no CAV, grade 2 is mild/moderate CAV and grade 3 is severe
  CAV.  Grade 4 is recorded at the time of death.   \cr
  }}

\keyword{datasets}
\eof
\name{logit}
\alias{logit}
\title{Logit function}
\description{Logit function}
\usage{logit(x)
}
\arguments{
  \item{x}{ }
}
\value{
  \eqn{log(x / (1 - x))}
}
\seealso{
  \code{\link{expit}} for inverse logit function
}
\keyword{}
\eof
\name{msm-internal}
\title{Internal msm functions}
\alias{msm-internal}
\alias{lik.msm}
\alias{lik.msmmisc}
\alias{getobs.msm}
\alias{observed.msm}
\alias{msm.process.covs}
\alias{msm.form.output}
\alias{msm.check.qmatrix}
\alias{msm.check.ematrix}
\alias{msm.check.consistency}
\alias{msm.check.state}
\alias{msm.check.model}
\alias{msm.check.times}
\alias{msm.check.tunit}
\alias{msm.check.qmatrix}
\alias{qematrix.msm}
\alias{qematrix.diagse.formstr}
\alias{qematrix.diagse.msm}
\alias{expsum}
\alias{expitsum}
\alias{qratio.se.msm}
\alias{transient.msm}
\alias{absorbing.msm}
\description{Auxiliary R functions used in the msm package. These are not
  meant to be called by the user}
\usage{

lik.msm(params, allinits, misc, subject, time, state, tostate, fromto,
        qvector, evector, covvec, constrvec, misccovvec, miscconstrvec,
        baseconstrvec, basemiscconstrvec, initprobs,
        nstates, nintens, nintenseffs, nmisc, nmisceffs, nobs, npts, ncovs, ncoveffs,
        nmisccovs, nmisccoveffs, covmatch, death, tunit, exacttimes, fixedpars, plabs)

getobs.msm(sim, obstimes, death, tunit)

observed.msm(x, times)

msm.process.covs(covariates, data, constraint, nobs, nmatrix)

msm.form.output(matrix, nstates, nmatrix, nmatrixeffs, npars, ncovs,
                constrvec, baseconstrvec, fixedpars, fixed, covlabels,
                params, covmat, foundse, params.offset)

msm.check.qmatrix(qmatrix)

msm.check.ematrix(ematrix, qmatrix)

msm.check.consistency(qmatrix, misc, fromto=F, subject=NULL, state,
                      tostate=NULL, time, death=FALSE, exacttimes=FALSE, tunit=NULL)

msm.check.state(nstates, state, fromto=FALSE, tostate=NULL)

msm.check.model(state, subject, qmatrix, fromto=NULL, tostate=NULL)

msm.check.times(time, subject)

msm.check.tunit(fromto, time, subject, timelag, tunit)

qematrix.msm(x, covariates="mean", which="intens", sojourn)

qematrix.diagse.msm(x, covariates="mean", which="intens", sojourn, ni,
nieffs, ivector, nc, constrvec, baseconstrvec, covlabels, covmeans, trsum)

qematrix.diagse.formstr(nir, inds, cur.i, ni, nc, coefs, offset, trsum)

expsum(inds, coefs)

expitsum(inds, coefs)

qratio.se.msm(x, ind1, ind2, covariates="mean")

transient.msm(x)

absorbing.msm(x)

}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{internal}
\eof
\name{msm}
\title{Multi-state Markov models}
\alias{msm}
\description{
  Fit a continuous-time Markov multi-state model by maximum
  likelihood. Observations of the process
  can be made at arbitrary times, or the exact times of
  transition between states can be known. 
  Covariates can be fitted to the transition intensities.
  When the true state is observed with error, a model can be fitted
  which simultaneously estimates the state transition intensities and
  misclassification probabilities, with optional covariates on both
  processes.
  
}
\usage{
msm ( formula, qmatrix, misc = FALSE, ematrix, inits, subject,
      covariates = NULL, constraint = NULL, misccovariates = NULL,
      miscconstraint = NULL, qconstraint=NULL, econstraint=NULL,
      covmatch = "previous", initprobs = NULL, 
      data = list(), fromto = FALSE, fromstate, tostate, timelag,
      death = FALSE, tunit = 1.0, exacttimes = FALSE,
      fixedpars = NULL, ... )
}
\arguments{
  \item{formula}{ A formula giving the vectors containing the observed
    states and the  corresponding observation times. For example,
    
    \code{states ~ times}

    See \code{fromto} for an alternative way to specify the
    data. Observed states should be in the set \code{1, \dots, n},
    where \code{n} is the number of states.
  }

  \item{qmatrix}{Matrix of indicators for the allowed transitions.
    If a transition is allowed from state \eqn{r} to state \eqn{s},
    then \code{qmatrix} should have \eqn{(r,s)} entry 1, otherwise
    it should have \eqn{(r,s)} entry 0. The diagonal of \code{qmatrix}
    is ignored. For example,\cr
    
    \code{
    rbind(
    c( 0, 1, 1 ),
    c( 1, 0, 1 ),
    c( 0, 0, 0 )
    )
  }\cr
  
    represents a 'health - disease - death' model, with transitions
    allowed from health to disease, health to death, disease to health, 
    and disease to death. 
  }

  \item{misc}{Set \code{misc = TRUE} if misclassification between
    observed and underlying states is to be modelled.}

  \item{ematrix}{
    (required when \code{misc == TRUE}) Matrix of indicators for the allowed
misclassifications. 
    The rows represent underlying states, and the columns represent
    observed states.
    If an observation of state \eqn{s} is possible when the subject
    occupies underlying state \eqn{r}, then \code{ematrix} should have
    \eqn{(r,s)} entry 1, otherwise
    it should have \eqn{(r,s)} entry 0. The diagonal of \code{ematrix}
    is ignored. For example, \cr

    \code{
      rbind(
    c( 0, 1, 0 ),
    c( 1, 0, 1 ),
    c( 0, 1, 0 )
    )
  }\cr
  
    represents a model in which misclassifications are only permitted
    between adjacent states. 
  }

  \item{inits}{(required) Vector of initial parameter estimates for the
    optimisation. These are given in the order

    - transition intensities (reading across first rows of intensity
    matrix, then second row ... )

    - covariate effects on log transition intensities

    - misclassification probabilities (reading across first row of
    misclassification matrix, then second row ...)

    - covariate effects on logit misclassification probabilities

    Covariate effects are given in the following order,

    - effects of first covariate on transition/misclassification matrix elements (reading across
    first row of matrix, then second row ...)

    - effects of second covariate ... 
  }

  \item{subject}{Vector of subject identification numbers, when the data
    are specified by \code{formula}. If missing, then all observations
    are assumed to be on the same subject. These must be sorted so that
    all observations on the same subject are adjacent. Ignored if
    \code{fromto == TRUE}.}

  \item{covariates}{Formula representing the covariates on the
  transition intensities, for example,

    \code{~ age + sex + treatment}
    
  }

  \item{constraint}{A list of one vector for each named covariate. The
  vector indicates which covariate effects on intensities are
  constrained to be equal. Take, for example, a model with five
  transition intensities and two covariates. Specifying\cr
    
    \code{constraint = list (age = c(1,1,1,2,2),  treatment = c(1,2,3,4,5))}\cr

    constrains the effect of age to be equal for the first three
    intensities, and equal for the fourth and fifth. The effect of
    treatment is assumed to be different for each intensity. Any vector of
    increasing numbers can be used as indicators. The intensity parameters are
    assumed to be ordered by reading across the rows of the
    transition matrix, starting at the first row.

    For categorical covariates, defined using \code{factor(covname)},
    specify constraints as follows:\cr

    \code{list(..., covnameVALUE1 = c(...), covnameVALUE2 = c(...), ...)}\cr
    
    where \code{VALUE1}, \code{VALUE2}, ... are the levels of the factor.
    Make sure the \code{contrasts} option is set appropriately, for
    example, the default \code{options(contrasts=c(contr.treatment,
      contr.poly))} sets the first (baseline) level of the factor to
    zero.

    To assume no covariate effect on a certain transition, set its
    initial value to zero and use the \code{fixedpars} argument to fix
    it during the optimisation.
    
  }

  \item{misccovariates}{A formula representing the covariates on the 
  misclassification probabilities, analogously to \code{covariates}.
  }

  \item{miscconstraint}{A list of one vector for each named covariate on
    misclassification probabilities. The vector indicates which
    covariate effects on misclassification probabilities are
    constrained to be equal, analogously to \code{constraint}.
  }

  \item{qconstraint}{A vector of indicators specifying which baseline
    transition intensities are equal. For example,
    
    \code{qconstraint = c(1,2,3,3)}

    constrains the third and fourth intensities to be equal, in a model
    with four allowed instantaneous transitions. 
  }

  \item{econstraint}{A similar vector of indicators specifying which
    baseline misclassification probabiliities are constrained to be
    equal. }
  
  \item{covmatch}{If \code{"previous"}, then time-dependent covariate
    values are taken from the observation at the start of the
    transition. If \code{"next"}, then the covariate value is taken from
    the end of the transition.}

  \item{initprobs}{Vector of assumed underlying state occupancy
    probabilities at the initial time of the process. Defaults to
    \code{c(1, rep(0, nstates-1))}, that is, in state 1 with a
probability of 1. 
  }

  \item{data}{Optional data frame in which to interpret the state, time,
    subject ID, covariate, fromstate, tostate and timelag vectors.}

  \item{fromto}{If \code{TRUE}, then the data are given as three vectors, 
    \emph{from-state, to-state, time-difference},
    representing the set of observed transitions between states, and the
    time taken by each one. Otherwise, the data are given by \code{formula},
    containing observation times, corresponding observed states, and a
    vector of corresponding subject identification numbers \code{subject}.
  }

  \item{fromstate}{ Starting states for the observed transitions
    (required if \code{fromto == TRUE} ). }

  \item{tostate}{ Finishing states for the observed transitions
    (required if \code{fromto == TRUE} ). }

  \item{timelag}{ Time difference between observing \code{fromstate}
    and \code{tostate}  (required if \code{fromto == TRUE} ). }

  \item{death}{If \code{TRUE}, then the final state represents
    death. This means that the time of entry into this state is known to
    within one day, and that the individual remains in this state for
    ever after. Defaults to \code{FALSE}. Only one absorbing state with
    this behaviour is permitted. }

  \item{tunit}{Unit in days of the given time vector (if \code{death == TRUE}).}

  \item{exacttimes}{If \code{TRUE}, then the times are assumed to
    represent the exact times of transition of the Markov
    process. Otherwise the transitions are assumed to take place at
    unknown occasions in between the observation times.}

  \item{fixedpars}{Vector of indices of parameters whose values will be
    fixed at their initial values during the optimisation. These
    correspond to indices of the \code{inits} vector, whose order is
    specified above.}

  \item{...}{Optional arguments to the general-purpose R
    optimization routine \code{\link{optim}}. Useful options include
    \code{method="BFGS"} for using a quasi-Newton optimisation
    algorithm, which can often be faster than the default Nelder-Mead.
    If the optimisation fails to converge, consider normalising the
    problem using, for example, \code{control=list(fnscale = 2500)}, for
    example, replacing 2500 by a number of the order of magnitude of the
    likelihood. If 'false' convergence is reported and the standard
    errors cannot be calculated due to a non-positive-definite Hessian,
    then consider tightening the tolerance criteria for convergence. If
    the optimisation takes a long time, intermediate steps can be
    printed using the \code{trace} argument of the control list. See
    \code{\link{optim}} for details.
  }
}
\value{
  A list of class \code{msm}, with components:

  \item{misc}{Logical value indicating whether the model includes
    misclassification.}
  \item{Qmatrices}{A list of matrices. The first component, labelled
    \code{logbaseline}, is a matrix containing the estimated
    transition intensities on the log scale with any covariates fixed at
    their means in the data. Each remaining component is a matrix giving the linear
    effects of the labelled covariate on the matrix of log
    intensities.  To extract an intensity matrix on the natural
    scale, at an arbitrary combination of covariate values, use the
    function \code{\link{qmatrix.msm}}.
  }
  \item{QmatricesSE}{The standard error matrices corresponding to
    \code{Qmatrices}.
  }
  \item{Ematrices}{A list of matrices. The first component, labelled
    \code{logitbaseline}, is the estimated misclassification probability
    matrix  with any covariates fixed at their means
    in the data. Each remaining component is a matrix giving the linear
    effects of the labelled covariate on the matrix of logit
    misclassification probabilities.   To extract a misclassification
    probability matrix on the natural scale, at an arbitrary combination
    of covariate values, use the function \code{\link{ematrix.msm}}}
  \item{EmatricesSE}{The standard error matrices corresponding to \code{Ematrices}}
  \item{sojourn}{
    A list with components:

    \code{mean} = estimated mean sojourn times in the transient states,
    with covariates fixed at their means.

    \code{se} = corresponding standard errors.
  }
  \item{minus2loglik}{Minus twice the maximised log-likelihood}
  \item{foundse}{Logical value indicating whether the Hessian was positive-definite
    at the supposed maximum of the likelihood.  If not, the covariance matrix of the
    parameters is unavailable. Furthermore, it is doubtful whether the optimisation
    has converged to the maximum. 
  }
  \item{estimates}{Vector of untransformed maximum likelihood estimates
    returned from \code{\link{optim}}, with intensities on the log scale
    and misclassification probabilities on the logit scale.}
  \item{estimates.t}{Vector of transformed maximum likelihood estimates
    with intensities ans probabilities on their natural scales.}
  \item{covmat}{Covariance matrix corresponding to \code{estimates}.}
  \item{data}{A list of constants and vectors giving the data, for use
    in post-processing.}
  \item{model}{A list of constants and vectors specifying the model, 
    for use in post-processing.}
}
\details{
  For models without misclassification,
  the likelihood is calculated in terms of the transition intensity
  matrix \eqn{Q}. When the data consist of observations of the Markov
  process at arbitrary times, the exact transition times are not known.
  Then the likelihood is calculated using the transition probability
  matrix \eqn{P(t) = exp(tQ)}. If state \eqn{i} is observed at time
  \eqn{t} and  state \eqn{j} is observed at time \eqn{u}, then the
  contribution to the likelihood from this pair of observations is
  the \eqn{i,j} element of \eqn{P(u - t)}. See, for example, Kay (1986),
  or Gentleman \emph{et al.} (1994).

  For models with misclassification, the likelihood for an individual
  with \eqn{k} observations is calculated by summing over the unknown
  state at each time,  producing a product of \eqn{k} matrices. The
  calculation is adapted from that in Satten and Longini (1996), and is
  also given by Jackson and Sharples (2002). 

  There must be enough information in the data on each state to estimate
  each transition rate, otherwise the likelihood will be flat and the
  maximum will not be found.  It may be appropriate to reduce the
  number of states in the model, or reduce the number of covariate
  effects, to ensure convergence.

  Choosing an appropriate set of initial values for the optimisation can
  also be important.  For flat likelihoods, 'informative' initial values
  will often be required. 
}
\references{
  Jackson, C.H., Sharples, L.D., Thompson, S.G. and Duffy, S.W. and
  Couto, E.  Multi-state Markov models for disease progression with
  classification error. \emph{The Statistician}, 52(2): 193--209 (2003)
    
  Jackson, C.H. and Sharples, L.D. Hidden Markov models for the
  onset and progresison of bronchiolitis obliterans syndrome in lung
  transplant recipients \emph{Statistics in Medicine}, 21(1): 113--128
  (2002).
    
  Kay, R.  A Markov model for analysing cancer markers and disease
  states in survival studies.  \emph{Biometrics} (1986) 42: 855--865.
  
  Gentleman, R.C., Lawless, J.F., Lindsey, J.C. and Yan, P.  Multi-state
  Markov models for analysing incomplete disease history data with
  illustrations for HIV disease.  \emph{Statistics in Medicine} (1994) 13(3):
  805--821.

  Satten, G.A. and Longini, I.M.  Markov chains with measurement error:
  estimating the 'true' course of a marker of the progression of human
  immunodeficiency virus disease (with discussion) \emph{Applied
    Statistics} 45(3): 275-309 (1996)
}

\seealso{
  \code{\link{simmulti.msm}}, \code{\link{print.msm}}, \code{\link{plot.msm}},
  \code{\link{summary.msm}}, \code{\link{qmatrix.msm}},
  \code{\link{pmatrix.msm}},  \code{\link{sojourn.msm}}, 
}
\examples{
data(aneur)
print(aneur$from[1:10])
print(aneur$to[1:10])
print(aneur$dt[1:10])
### four states corresponding to increasing disease severity,
### with progressive transitions only 
qmat <- rbind( c(0, 1, 0, 0), c(0, 0, 1, 0), c(0, 0, 0, 1), c(0, 0, 0,
0))

aneurysm.msm <- msm(data=aneur, fromto=TRUE, fromstate=from, tostate=to,
                    qmatrix=qmat, timelag=dt, death=FALSE, inits=c(0.001,
                    0.03, 0.3), method="BFGS", control=list(trace=2))

print(aneurysm.msm)
qmatrix.msm(aneurysm.msm) # Extract only the transition intensities from the printed results
pmatrix.msm(aneurysm.msm, 10) # Extract the 10 year transition probability matrix
sojourn.msm(aneurysm.msm) # Extract the mean sojourn times
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{odds.msm}
\title{Calculate tables of odds ratios for covariates on
  misclassification probabilities}
\alias{odds.msm}
\description{
  Odds ratios are computed by exponentiating the
  estimated covariate effects on the logit-misclassification
  probabilities.
}
\usage{
odds.msm(x, odds.scale = 1)
}
\arguments{
  \item{x}{Output from \code{\link{msm}} representing a fitted
    multi-state model.}

  \item{odds.scale}{Vector with same elements as number of covariates
    on misclassification probabilities. Corresponds to the increase in
    each covariate used to calculate its odds ratio. Defaults to all 1.}
}
\value{

  A list of tables containing odds ratio estimates, one table for each covariate.
  Each table has three columns, containing the odds ratio, and an
  approximate upper 95\% and lower 95\% confidence limit respectively
  (assuming normality of the estimator), for each misclassification
  probability.

}
\seealso{
  \code{\link{msm}}, \code{\link{hazard.msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{plot.msm}
\title{Plots of multi-state models}
\alias{plot.msm}
\description{
  This produces a plot of the expected probability of
  survival against time, from each transient state. Survival is defined
  as not entering the final absorbing state.
}
\usage{
\method{plot}{msm}(x, from, to, covariates, legend.pos, ...)
}
\arguments{

  \item{x}{Output from \code{\link{msm}}, representing a fitted
    multi-state model object}

  \item{from}{States from which to consider survival from. Defaults to
    the complete set of transient states. }

  \item{to}{Absorbing state to consider. Defaults to the
    highest-labelled absorbing state. }

  \item{covariates}{Covariate values for which to evaluate the expected
    probabilities.  This can either be:\cr

    the string \code{"mean"}, denoting the means of the covariates in
    the data (this is the default),\cr

    the number \code{0}, indicating that all the covariates should be
    set to zero,\cr

    or a list of values, with optional names. For example

    \code{list (60, 1)}

    where the order of the list follows the order of the covariates
    originally given in the model formula, or a named list, 

    \code{list (age = 60, sex = 1)}
  }

  \item{legend.pos}{Vector of the \eqn{x} and \eqn{y} position,
    respectively, of the legend.}
  
  \item{...}{Other arguments to the generic \code{plot} function}
}
\seealso{
  \code{\link{msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{pmatrix.msm}
\alias{pmatrix.msm}
\title{Transition probability matrix}
\description{
  Extract the estimated transition probability matrix from a fitted multi-state
  model for a given time interval, at a given set of covariate values. 
}
\usage{
pmatrix.msm(x, t, covariates="mean")
}
\arguments{

  \item{x}{A fitted multi-state model, as returned by \code{\link{msm}}.}

  \item{t}{The time interval to estimate the transition probabilities for.}

  \item{covariates}{
    The covariate values at which to estimate the transition
    probabilities.  This can either be:\cr

    the string \code{"mean"}, denoting the means of the covariates in
    the data (this is the default),\cr

    the number \code{0}, indicating that all the covariates should be
    set to zero,\cr

    or a list of values, with optional names. For example

    \code{list (60, 1)}

    where the order of the list follows the order of the covariates
    originally given in the model formula, or a named list, 

    \code{list (age = 60, sex = 1)}
  }
}
\value{
  The matrix of estimated transition probabilities \eqn{P(t)} in the given time. 
  Rows correspond to "from-state" and columns to "to-state". 
}
\details{
  For a continuous-time homogeneous Markov process with transition
  intensity matrix
  \eqn{Q},  the probability of occupying state \eqn{s} at time \eqn{u + t}
  conditional on occupying state \eqn{r} at time \eqn{u} is given by the
  \eqn{(r,s)} entry of the matrix \eqn{P(t) = exp(tQ)}.

  For non-homogeneous processes, where covariates and hence the
  transition intensity matrix vary but are piecewise-constant within
  the time interval \code{[u,
  u+t]}, the function \code{\link{pmatrix.piecewise.msm}} can be used.
  
}
\seealso{
  \code{\link{qmatrix.msm}},  \code{\link{pmatrix.piecewise.msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{}
\eof
\name{pmatrix.piecewise.msm}
\alias{pmatrix.piecewise.msm}
\title{Transition probability matrix for processes with piecewise-constant intensities}
\description{
  Extract the estimated transition probability matrix from a fitted multi-state
  model for a given time interval.  This is a generalisation of
  \code{\link{pmatrix.msm}} to non-time-homogeneous Markov models with
  piecewise-constant transition intensity matrices. 
}
\usage{
pmatrix.piecewise.msm(x, t1, t2, times, covariates)
}
\arguments{

  \item{x}{A fitted multi-state model, as returned by \code{\link{msm}}.}

  \item{t1}{The start of the time interval to estimate the transition probabilities for.}

  \item{t2}{The end of the time interval to estimate the transition probabilities
    for.}

  \item{times}{Cut points at which the transition intensity matrix changes.}

  \item{covariates}{
    A list with number of components one greater than the length of
    \code{times}.  Each component of the list is specified in the same
    way as the \code{covariates} argument to \code{\link{pmatrix.msm}}.
    The components correspond to the covariate values in the intervals
    
    \code{(t1, times[1]],  (times[1], times[2]], ...,
      (\times[length(times)], t2]}

    (assuming that all elements of \code{times} are in the interval
    \code{(t1, t2)}).
  }
}
\value{
  The matrix of estimated transition probabilities \eqn{P(t)} for the
  time interval \code{[t1, tn]}.  That is, the probabilities of
  occupying state \eqn{s} at time \eqn{tn}
  conditionally on occupying state \eqn{r} at time \eqn{t1}.
  Rows correspond to "from-state" and columns to "to-state". 
}
\details {
  Suppose a multi-state model, \code{x.msm}, has been fitted, in which
  the transition intensity matrix \eqn{Q(x(t))} is modelled in terms of
  time-dependent covariates \eqn{x(t)}.  The transition probability
  matrix \eqn{P(t_1, t_n)}{P(t1, tn)} for the time interval \eqn{(t_1, t_n)}{(t1, tn)} cannot be
  calculated from the estimated intensity matrix as
  \eqn{exp((t_n - t_1) Q}{exp((tn - t1) Q}, because \eqn{Q} varies within the interval
  \eqn{t_1, t_n}{t1, tn}.  However, if the covariates are piecewise-constant, 
  or can be approximated as piecewise-constant, then we can calculate
  \eqn{P(t_1, t_n)}{P(t1, tn)} by multiplying together individual matrices
  \eqn{P(t_i,
  t_{i+1}) = exp((t_{i+1} - t_i) Q}, calculated over intervals where Q is
  constant:

  \deqn {P(t_1, t_n) =  P(t_1, t_2) P(t_2, t_3) \dots P(t_{n-1}, t_n)} {P(t1, tn) =  P(t1, t2) P(t2, t3) \dots P(tn-1, tn)}.
  
}
\seealso{
  \code{\link{pmatrix.msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{}
\eof
\name{prevalence.msm}
\title{Tables of observed and expected prevalences}
\alias{prevalence.msm}
\description{
  This provides a rough indication of the goodness of fit of a
  multi-state model, by estimating the observed numbers of individuals
  occupying each state at a series of times, and comparing these with
  forecasts from the fitted model.   
}
\usage{
prevalence.msm(x, times, timezero=min(time), initstates, covariates="mean", misccovariates="mean")
}
\arguments{
  \item{x}{A fitted multi-state model, either with or without misclassification, produced
    by \code{\link{msm}}. The data for the fitted model must originally
    have been provided as a series of states and observation times, not in
    'from-state, to-state, time-difference' format.}
  \item{times}{Series of times at which to compute the observed and
    expected prevalences of states.}
  \item{timezero}{Initial time of the Markov process. Expected values
    are forecasted from here. Defaults to the minimum of the observation
    times given in the data. }
  \item{initstates}{Optional vector of the same length as the number of
    states. Gives the numbers of individuals occupying each state at the
    initial time. The default is those observed in the data. }
  \item{covariates}{Covariate values for which to forecast expected
    state occupancy.  See \code{\link{qmatrix.msm}}.  Defaults to the
    mean values of the covariates in the data set.}
  \item{misccovariates}{(Misclassification models only) Values of covariates on the misclassification
    probability matrix for which to forecast expected state occupancy.
    Defaults to the mean values of the covariates in the data set.}
}
\value{
  A list with components:
  
  \item{\code{Observed}}{Table of observed numbers of individuals in each state at
    each time}
  
  \item{\code{Observed percentages}}{Corresponding percentage of the
    individuals at risk at each time.}
  
  \item{\code{Expected}}{Table of corresponding expected numbers.}
  
  \item{\code{Expected percentages}}{Corresponding percentage of the
    individuals at risk at each time.}
  
}

\details{
  To compute `observed'  prevalences at a time \eqn{t}, individuals are
  assumed to be in the same state as at their last observation time preceding
  \eqn{t}.  This calculation is rather slow when there are a large
  number of individuals in the data.  

  The fitted transition probability matrix is used to forecast expected prevalences from the
  state occupancy at the initial time.  To
  produce the expected number in state \eqn{j} at time \eqn{t} after the
  start, the number of individuals under observation at time \eqn{t}
  (including those who have died, but not those lost to follow-up) is
  multiplied by the probability of transition between the initial state
  and state \eqn{j} in a time interval \eqn{t}.

  For misclassification models, this aims to assess the fit of the model for the \emph{observed}
  states to the data,  that is the combined Markov progression model for the true states and
  the misclassification model. Thus, expected prevalences of \emph{true}
  states are estimated from the assumed proportion
  occupying each state at the initial time using the fitted transition
  probabiliy matrix. The vector of expected prevalences of true states
  is then multiplied by the fitted misclassification probability matrix
  to obtain the expected prevalences of \emph{observed} states. 

  This approach only makes sense for processes where all individuals
  start at a common time.  
  
  For an example of this approach, see Gentleman \emph{et
    al.} (1994).

}

\references{
  Gentleman, R.C., Lawless, J.F., Lindsey, J.C. and Yan, P.  Multi-state
  Markov models for analysing incomplete disease history data with
  illustrations for HIV disease.  \emph{Statistics in Medicine} (1994) 13(3):
  805--821.
}

\seealso{
  \code{\link{msm}}, \code{\link{summary.msm}}}
}

\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{print.msm}
\title{Print a fitted multi-state model}
\alias{print.msm}
\description{
  The fitted transition intensity matrix, matrices containing
  covariate effects on intensities, and mean sojourn times from a fitted
  \code{\link{msm}} model are pretty printed, with their corresponding standard errors.
}
\usage{
\method{print}{msm}(x,\dots)
}
\arguments{
  \item{x}{output from \code{\link{msm}} representing a fitted
    multi-state model}
  \item{...}{further arguments passed to or from other methods}
}
\seealso{
  \code{\link{msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{qmatrix.msm}
\alias{qmatrix.msm}
\title{Transition intensity matrix}
\description{
  Extract the estimated transition intensity matrix, and the
  corresponding standard errors, from a fitted
  multi-state model at a given set of covariate values. 
}
\usage{
qmatrix.msm(x, covariates="mean", sojourn=FALSE)
}
\arguments{
 
  \item{x}{A fitted multi-state model, as returned by \code{\link{msm}}}.

  \item{covariates}{
    The covariate values at which to estimate the intensity matrix. 
    This can either be:\cr

    the string \code{"mean"}, denoting the means of the covariates in
    the data (this is the default),\cr

    the number \code{0}, indicating that all the covariates should be
    set to zero,\cr

    or a list of values, with optional names. For example

    \code{list (60, 1)}

    where the order of the list follows the order of the covariates
    originally given in the model formula, or a named list, 

    \code{list (age = 60, sex = 1)}
  }
  \item{sojourn}{Set to TRUE if the estimated sojourn times and their
    standard errors should also be returned.}
}

\value{
  A list with components:
  
  \item{\code{estimate}}{Estimated transition intensity matrix.}
  
  \item{\code{SE}}{Corresponding approximate standard errors.}  
  If \code{sojourn} is \code{TRUE}, extra components called
  \code{sojourn} and \code{sojournSE} are included, containing the
  estimate and standard errors respectively of the mean sojourn times in
  each transient state.

}

\details{
  Transition intensities and covariate effects are estimated on the log
  scale by \code{\link{msm}}. A covariance matrix is estimated from the
  Hessian of the maximised log-likelihood.  The delta method is used to
  obtain from these the standard error of the intensities on the natural
  scale at arbitrary covariate values. 
}

\seealso{
  \code{\link{pmatrix.msm}}, \code{\link{sojourn.msm}},
  \code{\link{deltamethod}}, \code{\link{ematrix.msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{qratio.msm}
\alias{qratio.msm}
\title{Estimated ratio of transition intensities}
\description{
  Compute the estimate and approximate standard error of the ratio of
  two estimated transition intensities from a fitted multi-state model
  at a given set of covariate values. 
}
\usage{
qratio.msm(x, ind1, ind2, covariates = "mean")
}
\arguments{
  \item{x}{A fitted multi-state model, as returned by
    \code{\link{msm}}}.

  \item{ind1}{Pair of numbers giving the indices in the intensity matrix
    of the numerator of the ratio, for example, \code{c(1,2)}. }

  \item{ind2}{Pair of numbers giving the indices in the intensity matrix
    of the denominator of the ratio, for example, \code{c(2,1)}. }

  \item{covariates}{
    The covariate values at which to estimate the intensities. 
    This can either be:\cr

    the string \code{"mean"}, denoting the means of the covariates in
    the data (this is the default),\cr

    the number \code{0}, indicating that all the covariates should be
    set to zero,\cr

    or a list of values, with optional names. For example

    \code{list (60, 1)}

    where the order of the list follows the order of the covariates
    originally given in the model formula, or a named list, 

    \code{list (age = 60, sex = 1)}
  }
}
\value{
  A list with components \code{estimate} and \code{se}, containing the
  estimate and standard error respectively of the ratio of intensities. 
}
\details{

  For example, we might want to compute the ratio of the progression
  rate and recovery rate for a fitted model \code{disease.msm} with a
  health state (state 1) and a disease state
  (state 2).  In this case, the progression rate is the (1,2) entry of
  the intensity matrix, and the recovery rate is the (2,1) entry.
  Thus to compute this ratio with covariates set to their means, we
  call

  \code{qratio.msm(disease.msm, c(1,2), c(2,1))} .

  Standard errors are estimated by the delta method. 
  
}
\seealso{
  \code{\link{qmatrix.msm}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{sim.msm}
\title{Simulate one individual trajectory from a continuous-time Markov model}
\alias{sim.msm}
\description{Simulate one realisation from a continuous-time
  Markov process up to a given time.
}
\usage{
sim.msm(qmatrix, maxtime, covs=NULL, beta=NULL, obstimes=NULL, start=1, mintime=0)
}
\arguments{
  
  \item{qmatrix}{ The transition intensity matrix of the
    Markov process. The diagonal of \code{qmatrix} is ignored,
    and computed as appropriate so that the rows sum to zero. For
    example, a possible \code{qmatrix} for a three state illness-death
    model with recovery is:

    \code{rbind(
    c( 0, 0.1, 0.02 ),
    c( 0.1, 0, 0.01 ),
    c( 0, 0, 0 )
    )}

  }

  \item{maxtime}{ Maximum time for the simulated process. }

  \item{covs}{Matrix of time-dependent covariates, with one row for each
  observation time and one column for each covariate.}

  \item{beta}{Matrix of linear covariate effects on log transition
    intensities. The rows correspond to different covariates, and the
    columns to the transition intensities. The intensities are ordered
    by reading across rows of the intensity matrix, starting with the
    first, counting the positive off-diagonal elements of the matrix.}

  \item{obstimes}{Vector of times at which the covariates are observed.}

  \item{start}{Starting state of the process. Defaults to 1.}

  \item{mintime}{Starting time of the process. Defaults to 0.}

}
\value{ A list with components,

  \item{states}{Simulated states through which the process moves}

  \item{times}{Exact times at which the process changes to the corresponding
    states}

  \item{qmatrix}{The given transition intensity matrix}
}
\details{
  The effect of time-dependent covariates on the transition intensity
  matrix for an individual is determined by assuming that the covariate is a step function
  which remains constant in between the individual's observation times.
}
\seealso{ \code{\link{simmulti.msm}}
}
\examples{

qmatrix <- rbind(
                 c(-0.2,   0.1,  0.1 ),
                 c(0.5,   -0.6,  0.1 ),
                 c(0,  0,  0)
                 )
sim.msm(qmatrix, 30)
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{simmulti.msm}
\title{Simulate multiple trajectories from a multi-state Markov model with arbitrary observation times}
\alias{simmulti.msm}
\description{Simulate a number of individual realisations from a
  multi-state Markov process. Observations of the process are made at
  specified arbitrary times for each individual. 
}
\usage{
simmulti.msm(data, qmatrix, beta, death = FALSE,  tunit = 1)
}

\arguments{

  \item{data}{A data frame with mandatory columns named \code{subject},
    corresponding to subject identification numbers, and \code{time},
    representing observation times. Other named columns of the data frame
    represent covariates.
  }
  
  \item{qmatrix}{
    The transition intensity matrix of the
    Markov process. The diagonal of \code{qmatrix} is ignored,
    and computed as appropriate so that the rows sum to zero. For
    example, a possible \code{qmatrix} for a three state illness-death
    model with recovery is:

    \code{rbind(
    c( 0, 0.1, 0.02 ),
    c( 0.1, 0, 0.01 ),
    c( 0, 0, 0 )
    )}

  }

  \item{beta}{Matrix of linear covariate effects on log transition
    intensities. The rows correspond to different covariates, and the
    columns to the transition intensities. The intensities are ordered
    by reading across rows of the intensity matrix, starting with the
    first, counting the positive off-diagonal elements of the matrix.}

  \item{death}{If \code{TRUE}, then the final state is an absorbing
    state whose time of entry is known to within one day.}

  \item{tunit}{Unit in days of the given time vector (if death is
    \code{TRUE}). For example if time is measured in years, then
    \code{tunit = 365}.
  }

}

\value{A data frame with columns,
  \item{subject}{Subject identification indicators}
  \item{time}{Observation times}
  \item{state}{Simulated state at the corresponding time}
  plus any supplied covariates. 
}
\details{
  
  \code{\link{sim.msm}} is called repeatedly to produce a simulated
  trajectory for each individual. The state at each specified
  observation time is then taken to produce a new column \code{state}.
  The effect of time-dependent covariates on the transition intensity
  matrix for an individual is determined by assuming that the covariate is a step function
  which remains constant in between the individual's observation times.
  If the subject enters an absorbing state, then only the first
  observation in that state is kept in the data frame. Rows corresponding to future
  observations are deleted. If \code{death} is \code{TRUE}, then the
  exact observation time of death is rounded up to the nearest \code{1 /
    tunit}.
}
\seealso{ \code{\link{sim.msm}}
}
\examples{
### Simulate 100 individuals with common observation times
sim.df <- data.frame(subject = rep(1:100, rep(13,100)), time = rep(seq(0, 24, 2), 100))
qmatrix <- rbind(c(-0.11,   0.1,  0.01 ),
                 c(0.05,   -0.15,  0.1 ),
                 c(0.02,   0.07, -0.09))
simmulti.msm(sim.df, qmatrix)
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{sojourn.msm}
\title{Mean sojourn times from a multi-state model}
\alias{sojourn.msm}
\description{
  Estimate the mean sojourn times in the transient states of a
  multi-state model and their standard errors.
}
\usage{
sojourn.msm(x, covariates="mean")
}
\arguments{

  \item{x}{A fitted multi-state model, as returned by \code{\link{msm}}}.

  \item{covariates}{
    The covariate values at which to estimate the mean sojourn times. This can either be:\cr

    the string \code{"mean"}, denoting the means of the covariates in
    the data (this is the default),\cr

    the number \code{0}, indicating that all the covariates should be
    set to zero,\cr

    a list of values, with optional names. For example,

    \code{list(60, 1)}, 
    where the order of the list follows the order of the covariates
    originally given in the model formula, or a named list, e.g.
    
    \code{list (age = 60, sex = 1)}
   
  }
  
}
\value{
    A list with components:

    \item{\code{estimate}}{Estimated mean sojourn times in the transient states.}

    \item{\code{se}}{Corresponding standard errors.}
}
\details{
  The mean sojourn time in a transient state \eqn{r} is estimated by
  \eqn{- 1 / q_{rr}}, where \eqn{q_{rr}} is the \eqn{r}th entry on the diagonal
  of the estimated transition intensity matrix.  Calls
  \code{\link{deltamethod}} to find approximate standard errors.
}
\seealso{
  \code{\link{msm}}, \code{\link{qmatrix.msm}}, \code{\link{deltamethod}}
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
\name{statetable.msm}
\alias{statetable.msm}
\title{Table of transitions}
\description{
  Calculates a frequency table counting the number of times each pair of
  states were observed in successive observation times.  
}
\usage{
statetable.msm(state, subject, data=NULL)
}
\arguments{
  \item{state}{Observed states, assumed to be ordered by time
  within each subject.}
  \item{subject}{Subject identification numbers corresponding to
    \code{state}. If not given, all observations are assumed to be on
    the same subject.}
  \item{data}{An optional data frame in which the variables represented
    by \code{subject} and \code{state} can be found.}
}
\value{
  A frequency table with starting states as rows and finishing states as
  columns.
}
\details{
  If the data are in "from state, to state, time lag" format, then this table
  can simply be produced by tabulating "from state" against "to state":

  \code{table(fromstate, tostate)}
}
\seealso{
  \code{\link{crudeinits.msm}}
}
\examples{
## Heart transplant data
data(heart)

## 148 deaths from state 1, 48 from state 2 and 55 from state 3.
statetable.msm(state, PTNUM, data=heart)

}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{}
\eof
\name{msm.summary}
\title{Summarise a fitted multi-state model}
\alias{summary.msm}
\alias{print.summary.msm}
\description{
  Summary method for fitted \code{\link{msm}} models. Produces a table of observed and
  expected state prevalences for each time. For all models, prints
  hazard ratios with confidence intervals for covariate effects.
}
\usage{
\method{summary}{msm}(object, times=NULL, timezero=NULL, initstates=NULL,
covariates="mean", misccovariates="mean", hazard.scale=NULL, \dots)
}
\arguments{
  \item{object}{A fitted multi-state model object, as returned by
    \code{\link{msm}}.}
  \item{times}{A sequence of times at which to compare observed
    and expected prevalences of each state. Defaults to
    \code{seq(min(times), max(times), (max(times) - min(times))/10).
    }
  }
  \item{timezero}{Initial time of the Markov process. Expected values
    are forecasted from here. Defaults to the minimum of the observation
    times given in the data. }
  \item{initstates}{ Optional vector of the same length as the number of
    states. Gives the numbers of individuals occupying each state at
    \code{timezero}. The default is that all individuals are in state 1.
  }
  \item{covariates}{Covariate values for which to forecast expected
    state occupancy.  See \code{\link{qmatrix.msm}}.  Defaults to the
    mean values of the covariates in the data set.}
  \item{misccovariates}{(Misclassification models only) Values of covariates on the misclassification
    probability matrix for which to forecast expected state occupancy.
    Defaults to the mean values of the covariates in the data set.}
  \item{hazard.scale}{Vector with same elements as number of covariates
    on transition rates. Corresponds to the increase in each covariate
    used to calculate its hazard ratio. Defaults to all 1.}  
  \item{...}{further arguments passed to or from other methods}
}

\note {
  The prevalence table is not available if the data were specified in
  \code{fromto} format in the call to {\code{\link{msm}}}. Expected
  prevalences only make sense for processes where all individuals
  start at a common time.
}

\value{
  A list of class \code{summary.msm}, with components:
  
  \item{prevalences}{Output from \code{\link{prevalence.msm}}}.

  \item{hazard}{Output from \code{\link{hazard.msm}}}.

  \item{hazard.scale}{Value of the \code{hazard.scale} argument}
    
}
\seealso{
  \code{\link{msm}}, \code{\link{print.summary.msm}}
  \code{\link{prevalence.msm}}, \code{\link{hazard.msm}}
}

\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{}
\eof
\name{totlos.msm}
\alias{totlos.msm}
\title{Total length of stay}
\description{
  Estimate the expected total length of stay in each transient state,
  for a given period of evolution of a multi-state model. This assumes that the
  transition rates do not change with time. 
}
\usage{
totlos.msm(x, start=1, fromt=0, tot=Inf, covariates="mean", ...)
}
\arguments{
  \item{x}{A fitted msm model, as given by
    \code{\link{msm}}. }
  \item{start}{State at the beginning of the period.}

  \item{fromt}{Time from which to estimate total length of
    stay. Defaults to 0, the beginning of the process.}
  
  \item{tot}{Time up to which total length of stay is estimated. Defaults
    to infinity, giving the expected time spent in the state until
    absorption. For models without an absorbing state, \code{t}
    must be specified.}

  \item{covariates}{
    The covariate values to estimate for.  This can either be:\cr

    the string \code{"mean"}, denoting the means of the covariates in
    the data (this is the default),\cr

    the number \code{0}, indicating that all the covariates should be
    set to zero,\cr

    or a list of values, with optional names. For example

    \code{list (60, 1)}

    where the order of the list follows the order of the covariates
    originally given in the model formula, or a named list, 

    \code{list (age = 60, sex = 1)}
      
  }

  \item{...}{Further arguments to be passed to the
    \code{\link{integrate}} function to control the numerical
    integration.}
}
\value{
  A vector of expected total lengths of stay for each transient state.
}
\details{
  The expected total length of stay in state \eqn{j} between times
  \eqn{t_1} and \eqn{t_2}, from the point of view of an individual in
  state \eqn{i} at time 0,
  is defined by the integral from \eqn{t_1} to
  \eqn{t_2} of the \eqn{i,j} entry of the transition probability matrix \eqn{P(t)}.
  As \eqn{P(t) = exp(tQ)} is not available explicitly in terms of
  \eqn{t} for a general Markov model, this integral is calculated
  numerically, using the \code{\link{integrate}} function.  This may
  take a long time for models with many states where \eqn{P(t)} is
  expensive to calculate. 

  For a model where the individual has only one place to go from each
  state, and each state is visited only once, for example a progressive
  disease model with no recovery or death, these are equal to the mean
  sojourn time in each state.
  However, consider a three-state health-disease-death model with
  transitions from health to disease, health to death, and disease to
  death, where everybody starts healthy.  In this case the mean sojourn
  time in the disease state will be greater than the expected length of
  stay in the disease state.  This is because the mean sojourn time in a
  state is conditional on entering the state, whereas the
  expected total time diseased is a forecast for a healthy
  individual,  who may die before contracting the disease. 

}
\seealso{
  \code{\link{sojourn.msm}}, \code{\link{integrate}}.
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{}
\eof
\name{viterbi.msm}
\title{Calculate the most likely path through underlying stages}
\alias{viterbi.msm}

\description{
  For a fitted multi state model with misclassification, the Viterbi
  algorithm recursively constructs the path through the underlying stages with the
  highest probability.
}

\usage{
viterbi.msm(x)
}
\arguments{
  \item{x}{A fitted multi-state model with misclassification, as
  produced by \code{\link{msm}}}
}
\value{
    A data frame with columns:

    \code{subject} = subject identification numbers

    \code{time} = times of observations

    \code{observed} = corresponding observed states

    \code{fitted} = corresponding fitted states found by Viterbi
    recursion.
}
\seealso{
  \code{\link{msm}}
}
\references{
  Durbin, R., Eddy, S., Krogh, A. and Mitchison, G. \emph{Biological
    sequence analysis}, Cambridge University Press, 1998.
}
\author{C. H. Jackson \email{chris.jackson@imperial.ac.uk}}
\keyword{models}
\eof
